function [ret] = cca_causaldensity(GC,PR)




% function calculate causal density given a matrix of Granger causalities
% 
% INPUTS:   GC: nvar by nvar matrix of Granger magnitudes
%           PR: nvar by nvar binary matrix of significant links (optional)
%           (if PR is present, GC will be filtered by PR)
%
% OUTPUT:   ret.cd:     causal density (bounded in range 0:1)
%           ret.cdw:    causal density weighted by  magnitude (not bounded)
%           ret.ucd:    vector of causal densities (per node)
%           ret.ucdw:   as above but weighted     


           

nvar = length(GC);
if nargin == 1,     % just GC matrix
    
    ret.cd = -1;
    ret.cdw = sum(sum(GC))/(nvar*(nvar-1));
    ret.ucd = -1;
    ret.ucdw = (sum(GC)/nvar) + ((sum(GC'))/nvar);
    
else                % filter by significance
    
    PR(PR~=0) = 1;  % ensure that all sig connections have value = 1
    ret.cd = sum(sum(PR))/(nvar*(nvar-1));
    ret.ucd = (sum(PR)/nvar) + ((sum(PR'))/nvar);
    GC(PR==0)=0;
    ret.cdw = sum(sum(GC))/(nvar*(nvar-1));
    ret.ucdw = (sum(GC)/nvar) + ((sum(GC'))/nvar);
end











